@@ -94,6 +94,7 @@ my $word_size=0;
 my $min_len_for_query=1;
 my $max_len_for_query=1000000000000000;
 my $estimated_depth=0;
+my $use_one_subread=0;
 
 my $blasr_path="";
 my $blasr_opt="";
@@ -184,6 +185,9 @@ if(defined($params{max_len_for_query})){
 if(defined($params{max_target_seqs})){
   $max_target_seqs = $params{max_target_seqs};
 }
+if(defined($params{use_one_subread})){
+  $use_one_subread = $params{use_one_subread};
+}
 
 printf STDERR ("#>- params -<#\n");
 printf STDERR ("input_for_database %s\n",$input_for_database);
@@ -196,6 +200,7 @@ printf STDERR ("evalue %g\n",$evalue);
 printf STDERR ("num_threads %d\n",$num_threads);
 printf STDERR ("valid_voters %s\n",$valid_voters);
 printf STDERR ("trim %d\n",$trim);
+printf STDERR ("use_one_subread %d\n",$use_one_subread);
 if($ca_path){
   printf STDERR ("ca_path %s\n",$ca_path);
 }
@@ -250,6 +255,8 @@ my $confident_length_coefficient = 0.75;
 my $date="";
 my $message="";
 
+my $pipefail = "set -o pipefail;";
+
 # mkdirs
 my $PWD = `pwd`;
 chomp $PWD;
@@ -285,6 +292,9 @@ if($from == 0)
   if($sprai_path){
     $dumbbell_filter = "$sprai_path/$dumbbell_filter";
   }
+  if(!$use_one_subread){
+    $dumbbell_filter = "cat";
+  }
   my $com1;
   my $com2;
 
@@ -302,7 +312,7 @@ if($from == 0)
       $PG0 = "$sprai_path/$PG0";
     }
     if($f_do){
-      $com1 = sprintf("time cat $parent | $PG0 - | $dumbbell_filter - | $PG - --prefix $tmp_dir/db%02d | gzip -c -1 > $child.tmp && mv $child.tmp $child",$from);
+      $com1 = sprintf("$pipefail time cat $parent | $PG0 - | $dumbbell_filter - | $PG - --prefix $tmp_dir/db%02d | gzip -c -1 > $child.tmp && mv $child.tmp $child",$from);
       `$com1`;
     }
     else{
@@ -321,7 +331,7 @@ if($from == 0)
     my $parent=$db_idfq_gz;
     if($f_do){
       if($min_len_for_query > 1){
-        $com2 = sprintf("time gzip -d -c $parent | $PG2 - $min_len_for_query -max_len $max_len_for_query | gzip -c -1 > $child.tmp && mv $child.tmp $child",$from);
+        $com2 = sprintf("$pipefail time gzip -d -c $parent | $PG2 - $min_len_for_query -max_len $max_len_for_query | gzip -c -1 > $child.tmp && mv $child.tmp $child",$from);
       }
       else{
         $com2 = sprintf("ln -s $parent $child");
@@ -356,7 +366,7 @@ for(my $index=$from; $index<$to; ++$index){
       $f_do = &do_or_not(\@parents,\$child);
       my $parent = $parents[0];
       if($f_do){
-        $com1 = sprintf("time gzip -d -c $parent | $PG1 -f - | makeblastdb -in - -dbtype nucl -out $tmp_dir/$preprefix%02d -title $preprefix%02d 1>$child.tmp && mv $child.tmp $child",$index,$index);
+        $com1 = sprintf("$pipefail time gzip -d -c $parent | $PG1 -f - | makeblastdb -in - -dbtype nucl -out $tmp_dir/$preprefix%02d -title $preprefix%02d 1>$child.tmp && mv $child.tmp $child",$index,$index);
       }
       else{
         $com1 = "sleep 0";
@@ -376,7 +386,7 @@ for(my $index=$from; $index<$to; ++$index){
       $f_do = &do_or_not(\@parents,\$child);
       my $parent = $parents[0];
       if($f_do){
-        $com2 = sprintf("time gzip -d -c $parent | $PG1 -f - | $PG2 - $partition -p $tmp_dir/$preprefix%02d 1>$child.tmp && mv $child.tmp $child", $index);
+        $com2 = sprintf("$pipefail time gzip -d -c $parent | $PG1 -f - | $PG2 - $partition -p $tmp_dir/$preprefix%02d 1>$child.tmp && mv $child.tmp $child", $index);
       }
       else{
         $com2 = "sleep 0";
@@ -445,7 +455,7 @@ for(my $index=$from; $index<$to; ++$index){
           my $f_do=1;
           $f_do = &do_or_not(\@parents,\$child);
           if($f_do){
-            $command .= sprintf("time cat $parent | $BLASTN -db $tmp_dir/$preprefix%02d -query - -evalue $evalue -outfmt '$outfmt' | $PG2 - | $PG3 - | $PG4 - | gzip -c -1 > $child.tmp && mv $child.tmp $child & ", $index);
+            $command .= sprintf("$pipefail time cat $parent | $BLASTN -db $tmp_dir/$preprefix%02d -query - -evalue $evalue -outfmt '$outfmt' | $PG2 - | $PG3 - | $PG4 - | gzip -c -1 > $child.tmp && mv $child.tmp $child & ", $index);
           }
           else{
             $command .= "sleep 0 & ";
@@ -480,7 +490,7 @@ for(my $index=$from; $index<$to; ++$index){
         my $f_do=1;
         $f_do = &do_or_not(\@parents,\$child);
         if($f_do){
-          $command .= sprintf("time gzip -d -c $parent | $PG1 - -finish -valid_depth $valid_depth -valid_read_length $valid_read_length | gzip -c -1 > $child.tmp && mv $child.tmp $child & ");
+          $command .= sprintf("$pipefail time gzip -d -c $parent | $PG1 - -finish -valid_depth $valid_depth -valid_read_length $valid_read_length | gzip -c -1 > $child.tmp && mv $child.tmp $child & ");
         }
         else{
           $command .= "sleep 0 & ";
